@@ -136,7 +136,7 @@ package Astro::Coord::ECI::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.109_01';
+our $VERSION = '0.110_01';
 our @ISA = qw{Exporter};
 
 use Carp;
@@ -181,10 +181,12 @@ BEGIN {
 	require Time::Local;
 
 	# sub time_gm
-	*time_gm = Time::Local->can( 'timegm' );
+	*time_gm = Time::Local->can( 'timegm_modern' ) ||
+	    Time::Local->can( 'timegm' );
 
 	# sub time_local
-	*time_local = Time::Local->can( 'timelocal' );
+	*time_local = Time::Local->can( 'timelocal_modern' ) ||
+	    Time::Local->can( 'timelocal' );
 
 	@time_routines = ( qw{ time_gm time_local __tle_year_to_Gregorian_year } );
 
@@ -1634,13 +1636,13 @@ __END__
 
 The author wishes to acknowledge Jean Meeus, whose book "Astronomical
 Algorithms" (second edition) published by Willmann-Bell Inc
-(L<http://www.willbell.com/>) provided several of the algorithms
+(L<https://www.willbell.com/>) provided several of the algorithms
 implemented herein.
 
 =head1 BUGS
 
 Bugs can be reported to the author by mail, or through
-L<http://rt.cpan.org/>.
+L<https://rt.cpan.org/>.
 
 =head1 AUTHOR
 
@@ -1648,7 +1650,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2019 by Thomas R. Wyant, III
+Copyright (C) 2005-2020 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
